@@ -27,10 +27,25 @@ import pkgutil
 
 def is_pip_installed(minversion=PIP_MINVERSION):
     try:
-        import pip  # @UnresolvedImport
-        ok = LooseVersion(pip.__version__) >= LooseVersion(minversion)
+        log.info("Try to load pip module...")
+        pipmodule = importlib.import_module('pip')
+        if hasattr(pipmodule,'__version__'):
+            ok = LooseVersion(pipmodule.__version__) >= LooseVersion(minversion)
+            log.info("Pip installed version %s" % pipmodule.__version__)
+        else:
+            ok = False
+            log.info("A too old version of pip is installed on your system")
+
+        # We clean up the imported pip module for test purpose
+        for m in [x for x in sys.modules if x.startswith('pip.')]:
+            del sys.modules[m]
+
+        del sys.modules['pip']
+        
+
     except:
         ok = False
+        log.info("No pip installed on your system")
         
     return ok
 
@@ -43,6 +58,8 @@ def get_a_pip_module(minversion=PIP_MINVERSION):
     if not local_pip:    
         if not is_pip_installed(minversion):
             try:
+                if 'http_proxy' in os.environ and 'https_proxy' not in os.environ:
+                    os.environ['https_proxy']=os.environ['http_proxy']
                 pipinstallscript = urllib2.urlopen('https://bootstrap.pypa.io/get-pip.py')
             except:
                 raise DistutilsError,"Pip (>=%s) is not install on your system and I cannot install it" % PIP_MINVERSION
@@ -64,24 +81,28 @@ def get_a_pip_module(minversion=PIP_MINVERSION):
                 log.info("   done.")
                 
             # Add the zipfile to sys.path so that we can import it
-            sys.path = [pip_zip] + sys.path
-            
+            sys.path.insert(0,pip_zip)
+            zi = zipimport.zipimporter(pip_zip)
+            pip = zi.load_module("pip") 
     
-        pipmodule = importlib.import_module('pip') 
+        else:
+            pip = importlib.import_module('pip')
+
+        local_pip.append(pip)
+    
+    # Prepare the CERT certificat for https download
             
-        # Prepare the CERT certificat for https download
-            
-        cert_path = os.path.join(tmpdir, "cacert.pem")
+    cert_path = os.path.join(tmpdir, "cacert.pem")
         
-        with open(cert_path, "wb") as cert:
-            cert.write(pkgutil.get_data("pip._vendor.requests", "cacert.pem"))
-            
-        os.environ.setdefault("PIP_CERT", cert_path)
+    certificate = pkgutil.get_data("pip._vendor.requests", "cacert.pem")
+
+    with open(cert_path, "wb") as cert:
+        cert.write(certificate)
            
-        assert LooseVersion(pipmodule.__version__) >= minversion, \
-               "Unable to find suitable version of pip get %s instead of %s" % (pipmodule.__version__,
-                                                                                minversion)
-        local_pip.append(pipmodule)
+    os.environ.setdefault("PIP_CERT", cert_path)
+          
+    assert hasattr(pip,'__version__') and LooseVersion(pip.__version__) >= LooseVersion(minversion), \
+               "Unable to find suitable version of pip"
        
     return local_pip[0]
             
